#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_EXPCDF_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_EXPCDF_HPP_INCLUDED

#include <nt2/statistics/include/functions/scalar/expcdf.hpp>

#endif
